@@ -119,7 +119,9 @@ class Form(SignalEvent, TabContent):
                     attributes.get('mode') or ['tree', 'form']))
             and self.screen.local_context == attributes.get('context')
             and self.attributes.get('search_value') == (
-                attributes.get('search_value')))
+                attributes.get('search_value'))
+            and self.attributes.get('tab_domain') == (
+                attributes.get('tab_domain')))
 
     def __hash__(self):
         return id(self)
@@ -638,7 +640,9 @@ class Form(SignalEvent, TabContent):
         menu_save.props.sensitive = not self.screen.readonly
 
         msg = name + ' / ' + str(signal_data[1])
-        if signal_data[1] < signal_data[2]:
+        if (signal_data[1] < signal_data[2]
+                and self.screen.limit is not None
+                and signal_data[2] > self.screen.limit):
             msg += _(' of ') + str(signal_data[2])
         self.status_label.set_text(msg)
         self.message_info()
