@@ -68,7 +68,7 @@ class WinForm(NoModal, InfoBar):
         self.accel_group = Gtk.AccelGroup()
         self.win.add_accel_group(self.accel_group)
 
-        readonly = self.screen.readonly or self.screen.group.readonly
+        readonly = self.screen.group.readonly
 
         self.but_ok = None
         self.but_new = None
@@ -355,7 +355,7 @@ class WinForm(NoModal, InfoBar):
         deletable = True
         if screen.current_record:
             deletable = screen.current_record.deletable
-        readonly = self.screen.readonly or self.screen.group.readonly
+        readonly = self.screen.group.readonly
         if signal_data[0] >= 1:
             name = str(signal_data[0])
             if self.domain is not None:
@@ -368,9 +368,11 @@ class WinForm(NoModal, InfoBar):
                 self.but_pre.set_sensitive(True)
             else:
                 self.but_pre.set_sensitive(False)
-            if access['delete'] and not readonly and deletable:
-                self.but_del.set_sensitive(True)
-                self.but_undel.set_sensitive(True)
+            self.but_del.set_sensitive(bool(
+                    not readonly
+                    and access['delete']
+                    and deletable))
+            self.but_undel.set_sensitive(bool(not readonly))
         else:
             self.but_del.set_sensitive(False)
             self.but_undel.set_sensitive(False)
@@ -399,7 +401,7 @@ class WinForm(NoModal, InfoBar):
         cancel_responses = [
             Gtk.ResponseType.CANCEL, Gtk.ResponseType.DELETE_EVENT]
         self.screen.current_view.set_value()
-        readonly = self.screen.readonly or self.screen.group.readonly
+        readonly = self.screen.group.readonly
         if (response_id not in cancel_responses
                 and not readonly
                 and self.screen.current_record is not None):
